==> ejc-zatopbpm-impl-3.0.0-20230918.100108-18-sources.jar: com/ejianc/zatopbpm/controller/BpmInfoController.java <==
package com.ejianc.zatopbpm.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.zatopbpm.bean.BpmInfoEntity;
import com.ejianc.zatopbpm.service.IBpmInfoService;
import com.ejianc.zatopbpm.vo.BpmInfoVO;

/**
 * 审批信息表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("bpmInfo")
public class BpmInfoController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBpmInfoService service;

    @Autowired
    private SessionManager sessionManager;


    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BpmInfoVO> queryDetail(Long id) {
    	BpmInfoEntity entity = service.selectById(id);
    	BpmInfoVO vo = BeanMapper.map(entity, BpmInfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BpmInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        IPage<BpmInfoEntity> page = service.queryPage(param,false);
        IPage<BpmInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), BpmInfoVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}

==> ejc-zatopbpm-impl-3.0.0-20230927.070948-64-sources.jar: com/ejianc/zatopbpm/controller/BpmInfoController.java <==
package com.ejianc.zatopbpm.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IModuleApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillTypeVO;
import com.ejianc.foundation.support.vo.ModuleVO;
import com.ejianc.foundation.usercenter.vo.UserVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.zatopbpm.vo.BpmConfigVO;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.zatopbpm.bean.BpmInfoEntity;
import com.ejianc.zatopbpm.service.IBpmInfoService;
import com.ejianc.zatopbpm.vo.BpmInfoVO;

/**
 * 审批信息表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("bpmInfo")
public class BpmInfoController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBpmInfoService service;
    @Autowired
    private IModuleApi moduleApi;
    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IUserApi userApi;

    @Autowired
    private SessionManager sessionManager;


    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BpmInfoVO> queryDetail(Long id) {
    	BpmInfoEntity entity = service.selectById(id);
    	BpmInfoVO vo = BeanMapper.map(entity, BpmInfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BpmInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();

        param.getParams().put("type", new Parameter(QueryParam.NE, null));

        if(param.getParams().get("moduleId")!=null){
            List<String> billTypeCodes = new ArrayList<>();
            CommonResponse<List<BillTypeVO>> moduleResponse = billTypeApi.queryAllBillTypeByModuleId(Long.parseLong(param.getParams().get("moduleId").getValue().toString()));
            if(moduleResponse.isSuccess()) {
                List<BillTypeVO> modules= moduleResponse.getData();
                for(int i=0;i<modules.size();i++) {
                    billTypeCodes.add(modules.get(i).getBillCode());
                }
            }
            param.getParams().remove("moduleId");
            if(billTypeCodes!=null && billTypeCodes.size()>0){
                param.getParams().put("billTypeCode", new Parameter(QueryParam.IN, billTypeCodes));
            }
        }
        /** 租户隔离 */
        IPage<BpmInfoEntity> page = service.queryPage(param,false);
        IPage<BpmInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), BpmInfoVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 弃审
     *
     * @param
     * @return
     */
    @RequestMapping(value = "/regainFree", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> regainFree(@RequestBody BpmInfoVO vo) {
        return service.regainFree(vo);
    }

}
